@@ -1,9 +1,9 @@
 package App::DPath;
-BEGIN {
-  $App::DPath::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.09-2-ge22ecd9
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Cmdline tool around Data::DPath
-$App::DPath::VERSION = '0.09';
+$App::DPath::VERSION = '0.10';
 use 5.008; # Data::DPath requires it
 
 1;
@@ -28,7 +28,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
